import os
import socket
from collections.abc import Generator
from contextlib import contextmanager
from pathlib import Path


@contextmanager
def change_cwd(new_dir: Path) -> Generator[None, None, None]:
    """Change the working directory temporarily."""
    old_dir = Path.cwd()
    os.chdir(new_dir)
    try:
        yield
    finally:
        os.chdir(old_dir)


def is_offline() -> bool:
    try:
        # Connect to Google's DNS server
        socket.create_connection(("8.8.8.8", 53), timeout=3)
    except OSError:
        return True
    else:
        return False
